=head1 NAME

CatalystX::Controller::ExtJS - Collection of useful ExtJS controllers

=head1 DESCRIPTION

This module provides controller classes which can be used in combination with ExtJS.
They simplify live in many ways and are easy to use.

=head1 CONTROLLERS

=head2 ImageChooser

See L<CatalystX::Controller::ExtJS::ImageChooser>.

=head2 REST

See L<CatalystX::Controller::ExtJS::REST>.

=head1 AUTHOR

Moritz Onken, C<onken@netcubed.de>

=head1 CONTRIBUTORS

Mario Minati

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2009 by Moritz Onken.

This is free software, licensed under:

  The (three-clause) BSD License

=cut